# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  web-ui-helper
# FileName:     log.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/28
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
import logging

logger = logging.getLogger("root")


def reset_airtest_loglevel(loglevel: str = "error"):
    log = logging.getLogger("airtest")
    if loglevel == "debug":
        log.setLevel(logging.DEBUG)
    elif loglevel == "info":
        log.setLevel(logging.INFO)
    elif loglevel == "warning":
        log.setLevel(logging.WARNING)
    else:
        log.setLevel(logging.ERROR)



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  web-ui-helper
# FileName:     ctrip_flight.py
# Description:  解析携程航班
# Author:       mfkifhss2023
# CreateDate:   2024/05/05
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
from decimal import Decimal
from selenium import webdriver
from pandas import DataFrame, set_option

from web_ui_helper.common.webdriver import Locator
from web_ui_helper.selenium.frame.browser import get_sub_element

"""
display.max_rows:     设置要显示的最大行数
display.max_columns:  设置要显示的最大列数
display.width:        设置显示的宽度，以字符数为单位
display.precision:    设置浮点数的精度
display.max_colwidth: 设置要显示的列的最大宽度，以字符数为单位
"""

# 设置要显示的最大行数和列数
set_option('display.width', 65535)
set_option('display.max_rows', 50)
set_option('display.max_columns', 1024)
set_option('display.max_colwidth', 100)
# 设置打印格式，使列头和行内容对齐
set_option('display.unicode.east_asian_width', True)


class DesktopFlight:

    @classmethod
    def parse_data(cls, driver: webdriver, elements_data: dict) -> DataFrame:
        index_regx = './/div[@index="{}"]'
        price_regx = './/span[@class="price"]'
        airline_regx = './/div[@class="flight-airline"]/div[@class="airline-name"]'
        plane_no_regx_1 = './/div[@class="plane"]/div[@class="plane"]/span'
        plane_no_regx_2 = './/div[@class="flight-airline"]/div[@class="plane"]'
        depart_time_regx = './/div[@class="depart-box"]/div[@class="time"]'
        depart_airport_regx = './/div[@class="depart-box"]/div[@class="airport"]/span'
        arrive_time_regx = './/div[@class="arrive-box"]/div[@class="time"]'
        arrive_airport_regx = './/div[@class="arrive-box"]/div[@class="airport"]/span'
        columns = [
            "index", "plane_no", "airline", "plane_type", "price", "price_uint",
            "depart_time", "depart_airport", "arrive_time", "cross_days", "arrive_airport"
        ]
        df = DataFrame(columns=columns)
        for index, element in elements_data.items():
            element = driver.find_element(Locator.get("xpath"), index_regx.format(index))
            # print(element.get_attribute('outerHTML'))
            price_element = get_sub_element(element=element, locator="xpath", regx=price_regx, interval=1, loop=3)
            price = price_element.text.strip() if price_element else ""
            airline_element = get_sub_element(
                element=element, locator="xpath", regx=airline_regx, interval=1, loop=3
            )
            airline = airline_element.text.strip() if airline_element else ""
            plane_no = get_sub_element(element=element, locator="xpath", regx=plane_no_regx_1, interval=1, loop=3)
            if plane_no:
                plane_no_slice = plane_no.text.strip().split()
                plane_no = plane_no_slice[0].strip()
                plane_type = plane_no_slice[1].strip()
            else:
                plane_no = element.find_element(Locator.get("xpath"), plane_no_regx_2)
                plane_no = plane_no.get_attribute('id').split("_")[0].split("-")[1].strip()
                plane_type = ""
            depart_time_element = get_sub_element(
                element=element, locator="xpath", regx=depart_time_regx, interval=1, loop=3
            )
            depart_time = depart_time_element.text.strip() if depart_time_element else ""
            arrive_time_element = get_sub_element(
                element=element, locator="xpath", regx=arrive_time_regx, interval=1, loop=3
            )
            arrive_time_slice = arrive_time_element.text.strip().split("\n") if arrive_time_element else list()
            depart_airport_element = get_sub_element(
                element=element, locator="xpath", regx=depart_airport_regx, interval=1, loop=3
            )
            depart_airport = depart_airport_element.text.strip() if depart_airport_element else ""
            arrive_airport_element = get_sub_element(
                element=element, locator="xpath", regx=arrive_airport_regx, interval=1, loop=3
            )
            arrive_airport = arrive_airport_element.text.strip() if arrive_airport_element else ""
            # 逐行添加数据
            new_row = dict(
                index=index, airline=airline, plane_no=plane_no, plane_type=plane_type,
                arrive_time=arrive_time_slice[0] if len(arrive_time_slice) > 0 else "",
                cross_days=arrive_time_slice[1] if len(arrive_time_slice) > 1 else "",
                depart_time=depart_time, price=Decimal(price[1:]), price_uint=price[:1], depart_airport=depart_airport,
                arrive_airport=arrive_airport
            )
            # 添加新行数据
            df.loc[len(df)] = new_row
        return df



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  web-ui-helper
# FileName:     date_extend.py
# Description:  TODO
# Author:       mfkifhss2023
# CreateDate:   2024/04/29
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
from datetime import datetime, timedelta

standard_date_format = "%Y-%m-%d %H:%M:%S"


def get_current_datetime_int_str() -> str:
    current_time = datetime.now()
    # 将当前时间格式化为字符串，精确到毫秒
    time_string = current_time.strftime('%Y-%m-%d %H:%M:%S.%f')
    return "{}{}{}{}{}{}{}".format(
        time_string[0:4], time_string[5:7], time_string[8:10],
        time_string[11:13], time_string[14:16], time_string[17:19], time_string[20:23]
    )


def get_datetime_area(date_str: str) -> tuple:
    if len(date_str) == 16:
        date_str = "{}:00".format(date_str)
    dt = datetime.strptime(date_str, standard_date_format)
    # 获取当天的0点时间
    first_time = datetime(dt.year, dt.month, dt.day, 0, 0, 0)
    six_time = datetime(dt.year, dt.month, dt.day, 6, 0, 0)
    twelve_time = datetime(dt.year, dt.month, dt.day, 12, 0, 0)
    eighteen_time = datetime(dt.year, dt.month, dt.day, 18, 0, 0)
    # end_time = datetime(dt.year, dt.month, dt.day, 23, 59, 59)
    if first_time <= dt < six_time:
        return 1, "凌晨 0~6点"
    elif six_time <= dt < twelve_time:
        return 2, "上午 6~12点"
    elif twelve_time <= dt < eighteen_time:
        return 3, "下午 12~18点"
    else:
        return 4, "晚上 18~24点"


def iso_to_standard_datestr(datestr: str, time_zone_step: int) -> str:
    """iso(2024-04-21T04:20:00Z)格式转 标准的时间格式(2024-01-01 00:00:00)"""
    dt_str = "{} {}".format(datestr[:10], datestr[11:-1])
    dt = datetime.strptime(dt_str, standard_date_format)
    dt_step = dt + timedelta(hours=time_zone_step)
    return dt_step.strftime(standard_date_format)
